import { fetcher } from "lib/fetcher";
import { useState } from "react";
import { InputGroup } from "react-bootstrap";
import useSWR from "swr";

import { BookDataResolved } from "database/services/service.typings";

import SearchableDropdown from "components/forms/SearchableDropdown";

export default function RerenderForm() {
    const {
        data: books,
        isValidating,
        error,
    } = useSWR<BookDataResolved[]>("/api/books", fetcher);

    const [bookId, setBookId] = useState<string>();
    const [message, setMessage] = useState<string>();

    const selectedBook = books?.find((book) => String(book.id) == bookId);

    if (isValidating) {
        return <p>Loading...</p>;
    }

    if (error) {
        return <p>Error: {error.message}</p>;
    }

    if (message) {
        return <p>{message}</p>;
    }

    return (
        <div>
            <InputGroup>
                <SearchableDropdown
                    options={books.map((book) => {
                        return {
                            value: String(book.id),
                            label: book.id + " " + book.title,
                        };
                    })}
                    onSelect={(option) => {
                        setBookId(option.value);
                    }}
                />

                <InputGroup.Text id="basic-addon3">
                    {selectedBook?.id} {selectedBook?.title}
                </InputGroup.Text>
            </InputGroup>

            <button
                onClick={() => {
                    //Post request
                    if (bookId) {
                        setBookId(undefined);
                        // enable loading
                        setMessage("Loading...");

                        fetch("/api/admin/rerenderPreviews", {
                            method: "POST",
                            headers: {
                                "Content-Type": "application/json",
                            },
                            body: JSON.stringify({
                                book_id: bookId,
                            }),
                        }).then((res) => {
                            if (res.status == 200) {
                                setMessage("Success");
                            } else {
                                setMessage("Error");
                            }
                        });
                    }
                }}
            >
                Rerender
            </button>
        </div>
    );
}
