import { fetcher } from "lib/fetcher";
import { ApiError } from "pages/api/_service";
import { PermissionACLDataResolved } from "pages/api/books/[id]/edit/get_acl";
import { BookOwner } from "pages/api/books/[id]/edit/get_owner";
import { useContext, useEffect, useState } from "react";
import { Alert, Button, Form, InputGroup } from "react-bootstrap";
import useSWR from "swr";

import { EditBookContext } from ".";

import styles from "./AccessEditor.module.scss";

export const TransferOwner = () => {
    const { book } = useContext(EditBookContext);

    const [newOwner, setNewOwner] = useState(undefined);
    const { mutate: mutateOwner } = useSWR<BookOwner>(
        `/api/books/${book.id}/edit/get_owner`,
        fetcher
    );
    const { mutate: mutateACL } = useSWR<PermissionACLDataResolved[]>(
        `/api/books/${book.id}/edit/get_acl`,
        fetcher
    );

    const [error, setError] = useState<string>(undefined);
    const [query, setQuery] = useState<string>("");

    // Feedback
    const close = () => {
        setError(undefined);
        setNewOwner(undefined);
    };
    const close_btn = (
        <button onClick={close}>
            <i className="bi bi-x"></i>
        </button>
    );
    const [bc, setBC] = useState(undefined);

    const submit = async (e) => {
        e.preventDefault();
        e.stopPropagation();

        if (query == "") {
            setError("Please enter a valid email or group name!");
            return;
        }

        await fetch(`/api/books/${book.id}/edit/set_owner`, {
            method: "POST",
            headers: {
                "Content-Type": "application/json",
            },
            body: JSON.stringify({ entity_name: query }),
        })
            .then(async (res) => {
                if (res.ok) {
                    return (await res.json()) as BookOwner;
                } else {
                    const error = (await res.json()) as ApiError;
                    throw new Error(error.details);
                }
            })
            .then((owner) => {
                setError(undefined);
                setNewOwner(owner);
                mutateOwner();
                mutateACL();
            })
            .catch((err) => {
                setNewOwner(undefined);
                setError(err.message);
            });
    };

    useEffect(() => {
        if (newOwner) {
            setBC("#447c5e");
            //Timeout
            setTimeout(() => {
                setBC(undefined);
            }, 300);
        }
        if (error) {
            setBC("#c44d58");
            setTimeout(() => {
                setBC(undefined);
            }, 300);
        }
    }, [newOwner, error]);

    return (
        <div className={styles.container}>
            <h2>Transfer Ownership</h2>
            <p>
                Use the form below to transfer the ownership of this book to
                another user or a group. Attention this might remove your
                permissions to this book!
            </p>
            <Alert
                variant="success"
                show={newOwner ? true : false}
                className={styles.alert}
                transition={false}
                style={{
                    borderColor: bc,
                    animation: "border-color 0.2s ease-in-out 0.2s",
                }}
            >
                {close_btn}
                Successfully transferred ownership to {
                    newOwner?.entity_type
                }{" "}
                <span>{newOwner?.entity_name}!</span>
            </Alert>
            <Alert
                variant="danger"
                show={error ? true : false}
                className={styles.alert}
                transition={false}
                style={{
                    borderColor: bc,
                    animation: "border-color 0.2s ease-in-out 0.2s",
                }}
            >
                {close_btn}
                {error}
            </Alert>
            <form onSubmit={submit}>
                <InputGroup className="p-3">
                    <Form.Control
                        type="text"
                        placeholder="Email or group name"
                        aria-label="search"
                        value={query}
                        onChange={(e) => setQuery(e.target.value)}
                    />
                </InputGroup>
                <div className={styles.apply_btn}>
                    <Button variant="danger" type="submit">
                        <i className="bi bi-exclamation-diamond"></i> Transfer
                        Ownership <i className="bi bi-exclamation-diamond"></i>
                    </Button>
                </div>
            </form>
        </div>
    );
};
