import { useEffect } from "react";

import Footer from "./Footer";
import Navbar from "./Navbar";
import Sidebar from "./Sidebar";

import styles from "./DefaultLayout.module.scss";

export type DefaultLayoutProps = {
    children: React.ReactNode;
    title?: string;
};

/** Default layout which shows navbar, footer and the sidebar with configurable
 * navigation links.
 */
export function DefaultLayoutWithSidebar({
    children,
    title = undefined,
}: DefaultLayoutProps) {

    const computeHeight = () => {
        const doc = document.documentElement;
        doc.style.setProperty('--doc-height', `${window.innerHeight}px`);
    }

    useEffect(() => {
        window.addEventListener('resize', computeHeight);
        computeHeight();
    }, []);

    return (
        <div className="d-flex flex-column" style={{
            height: "var(--doc-height)",
        }}>
            <Navbar>
                {title ? (
                    <div className="me-auto navbar-title">{title}</div>
                ) : null}
            </Navbar>
            <main className="d-flex" style={{ flex: "1", overflow: "hidden" }}>
                <Sidebar />
                <div className={styles.content}>{children}</div>
            </main>
            <Footer />
        </div>
    );
}

export function DefaultLayout({
    children,
    title = undefined,
}: DefaultLayoutProps) {

    const computeHeight = () => {
        const doc = document.documentElement;
        doc.style.setProperty('--doc-height', `${window.innerHeight}px`);
    }

    useEffect(() => {
        window.addEventListener('resize', computeHeight);
        computeHeight();
    }, []);

    return (
        <div className="d-flex flex-column" style={{
            height: "var(--doc-height)",
        }}>
            <Navbar>
                {title ? (
                    <div className="me-auto navbar-title">{title}</div>
                ) : null}
            </Navbar>
            <main className="d-flex" style={{ flex: "1", overflow: "hidden" }}>{children}</main>
            <Footer />
        </div>
    );
}
