/* eslint-disable @typescript-eslint/no-unused-vars */
import { ChangeEvent } from "react";

import styles from "./Form.module.scss";

export const EmailInput = ({
    isValid = false,
    isInvalid = false,
    invalidFeedback = undefined,
    onInput = (e: ChangeEvent<HTMLInputElement>) => {
        return;
    },
}) => {
    if (!invalidFeedback) {
        invalidFeedback = "Not a valid email address or does already exist.";
    }
    const input_props = {
        name: "email",
        id: "email",
        type: "text",
        autoComplete: "email",
        onInput,
    };
    return (
        <Input
            isInvalid={isInvalid}
            isValid={isValid}
            invalidFeedback={invalidFeedback}
            label="Email"
            input_props={input_props}
        />
    );
};

export const PasswordInput = ({
    isValid = false,
    isInvalid = false,
    onInput = (e: ChangeEvent<HTMLInputElement>) => {
        return;
    },
}) => {
    const invalidFeedback =
        "Password must be at least 10 characters long and contain at least one special character.";
    const input_props = {
        name: "password",
        id: "password",
        type: "password",

        autoComplete: "new-password",
        onInput,
    };
    return (
        <Input
            isInvalid={isInvalid}
            isValid={isValid}
            invalidFeedback={invalidFeedback}
            label="Password"
            input_props={input_props}
        />
    );
};

export const ConfirmPasswordInput = ({
    isValid = false,
    isInvalid = false,
    onInput = (e: ChangeEvent<HTMLInputElement>) => {
        return;
    },
}) => {
    const invalidFeedback = "Passwords do not match";
    const input_props = {
        name: "confirm_password",
        id: "confirm_password",
        type: "password",
        autoComplete: "new-password",
        onInput,
    };
    return (
        <Input
            isInvalid={isInvalid}
            isValid={isValid}
            invalidFeedback={invalidFeedback}
            label="Confirm password"
            input_props={input_props}
        />
    );
};

/** General input for form
 * Allows to define feedbacks for valid and invalid states
 *
 * @param isValid - if input is valid
 * @param isInvalid - if input is invalid
 * @param validFeedback - element show in
 * @param invalidFeedback -
 */
export const Input = ({
    isValid = false,
    isInvalid = false,
    validFeedback = null,
    invalidFeedback = null,
    input_props = { name: "inp" },
    label = "label",
}) => {
    let cls_extra = isValid ? ` ${styles.valid}` : "";
    cls_extra += isInvalid ? ` ${styles.inValid}` : "";

    let bootstrap_extra = isValid ? " is-valid" : "";
    bootstrap_extra += isInvalid ? " is-invalid" : "";

    return (
        <div className="d-flex flex-column">
            <div className={styles.inputField + " form-outline mb-3"}>
                <input
                    className={
                        "w-100 form-control form__input" + bootstrap_extra
                    }
                    placeholder=" "
                    {...input_props}
                />
                <label htmlFor={input_props.name}>{label}</label>
            </div>
            <div className={styles.feedback + cls_extra}>
                {isValid ? validFeedback : null}
                {isInvalid ? invalidFeedback : null}
            </div>
        </div>
    );
};
