import image_tablet from "@img/frontpage/tablet.webp";
import Image from "next/image";
import Link from "next/link";

import Section from "./section";

import hero from "./hero.module.scss";
/** Hero section of the frontpage
 *
 */
export default function Hero() {
    return (
        <div className={hero.wrapper}>
            <Section accents>
                <>
                    <div className={hero.title}>
                        <h1>Snip</h1>
                        <h2>The user focused & open-source digital Lab Book</h2>
                    </div>
                    <div className={hero.content}>
                        <div className={hero.text}>
                            <p>
                                Our platform empowers scientists, researchers,
                                and innovators like you to record, organize, and
                                share your groundbreaking discoveries with
                                precision and ease. With a user-first interface
                                and live collaboration support, we offer the
                                perfect tool for your documentation workflow.
                            </p>
                            <p>
                                Merge the charm of traditional analog
                                documentation with modern digital convenience.
                                Our digital Lab Book creates a bridge between
                                past and future. Just as you would{" "}
                                <q>glue in</q> notes on paper, our platform
                                effortlessly integrates digital elements,
                                preserving tactile familiarity within a digital
                                environment.
                            </p>
                        </div>
                        <div className={hero.imgWrapper}>
                            <Image
                                src={image_tablet}
                                alt="Snip running on a wacom tablet"
                                fill
                                style={{
                                    objectFit: "cover",
                                    objectPosition: "center",
                                }}
                            />
                        </div>
                    </div>
                    <div className={hero.buttonsWrapper}>
                        <hr />
                        <div className={hero.buttons}>
                            <Link href="/signup" className={hero.signup}>
                                <button
                                    type="button"
                                    className="btn btn-primary"
                                >
                                    Sign Up
                                </button>
                            </Link>
                            <Link href="/login" className={hero.login}>
                                <button className="btn btn-outline-secondary">
                                    Log In
                                </button>
                            </Link>
                        </div>
                    </div>
                </>
            </Section>
        </div>
    );
}
