# Viewer components

In this folder you can find all the components that are used to display a page from
a eLab book.

The `tools` folder contains all the components that are used to manipulate
the current page. This can be multiple tools, like a pen,
a highlighter, just allowing to resize the page.

Normally a viewer is paired with a `toolbar`, which can be used to switch between tools. And shows
additional information about the current tool.

## Usage with tools

If you want to use tools please use the `registerViewer` factory function. It automatically sets the correct context for all the tools.

```jsx
import { PageViewer } from "components/viewer/page";
import { registerViewer } from "components/viewer/";

export default function MyPage() {

    const pageData = ...;

    const desiredTools = ["movePage"];
    const initialActiveTool = undefined;
    const {ViewerContext, ToolBar} = registerViewer(desiredTools);

    return (
        <ViewerContext>
            <Sidebar/>
            <div
                style={{
                    position: "relative",
                    display: "flex",
                    flex: 1,
                    width: "100px",
                }}
            >
                <ToolBar/>
                <PageViewer />
            </div>
        </ViewerContext>
    );
}
```

Alternatively, this can be setup manually. It is a bit confusing to setup yourself, as all tools share a toolbar context which has to be defined before the tool contexts.

## Usage without tools

You can also use a viewer without tools. In this case you can use the `PageContextProvider` to set the page data. This is the most basic setup.

```jsx
import { PageViewer } from "components/viewer/page";

export default function MyPage() {

    const pageData = ...;

    return (
        <PageContextProvider>
            <PageViewer />
        </PageContextProvider>
    );
}

```
