import { MultiPageViewer, PagesContextProvider } from "./page";
import { SidebarContextProvider } from "./sidebar";
import { createToolbar, ToolBarProvider } from "./toolbar";
import { getProvider } from "./tools";
import { Tool } from "./tools/typing";

/** Factory function to create a viewer.
 * Returns a context provider and a toolbar component.
 * The context provider should be used to wrap all viewer components
 * including the toolbar.
 */
export function viewer_factory(tools: Tool[]) {
    const toolProvider = tools.map((tool) => getProvider(tool));
    // Add default tool
    toolProvider.push(getProvider(undefined));

    const ViewerContext = ({ children }: { children: React.ReactNode }) => {
        return (
            <PagesContextProvider>
                <SidebarContextProvider>
                    <ToolBarProvider>
                        {toolProvider.reduce((acc, Provider, i) => {
                            return <Provider key={i}>{acc}</Provider>;
                        }, children)}
                    </ToolBarProvider>
                </SidebarContextProvider>
            </PagesContextProvider>
        );
    };

    const Toolbar = createToolbar(tools);

    return {
        ViewerContext,
        Toolbar,
        Viewer: MultiPageViewer,
    };
}
