import Image from "next/image";
import { useContext } from "react";

import { SidebarContext } from ".";

import { Book } from "controller/book";

import styles from "./sidebar.module.scss";

export default function LayoutSwitchBtn({ book }: { book: Book }) {
    const { activePageId, setActivePageId } = useContext(SidebarContext);

    const isMultiPage = activePageId && activePageId.length >= 2;

    /** Remove last page or add next page
     *
     */
    const onClick = () => {
        if (isMultiPage) {
            setActivePageId([activePageId[0]]);
        } else {
            const page = book.pages.find((p) => p.id === activePageId[0]);
            if (!page) return;
            const next_page = book.pages.find(
                (p) => p.page_number === page.page_number + 1
            );
            if (next_page) setActivePageId([...activePageId, next_page.id]);
            else {
                const prev_page = book.pages.find(
                    (p) => p.page_number === page.page_number - 1
                );
                if (prev_page) setActivePageId([prev_page.id, activePageId[0]]);
            }
        }
    };

    return (
        <div className={styles.layoutSwitchBtn} data-active={isMultiPage}>
            <button className="btn" onClick={onClick}>
                <Image
                    src={
                        isMultiPage
                            ? "/img/viewer/layout_single.svg"
                            : "/img/viewer/layout_split.svg"
                    }
                    alt="Fullscreen"
                    fill
                />
            </button>
        </div>
    );
}
