import { Dispatch, useCallback, useState } from "react";
import ProgressBar from "react-bootstrap/ProgressBar";
import { useDropzone } from "react-dropzone";

import { Book } from "controller/book";

import styles from "./sidebar.module.scss";

/** This tool and the corresponding api endpoint
 * need major refactoring. It is currently a mess
 * and should be rewritten from scratch.
 * Desired features should be to upload snips via
 * their data object. Such that client and server
 * can easily sync snips.
 *
 * The full snip is send back in another place see book event listener
 *
 */
export default function UploadForm({
    book,
    setActiveSnipId = null,
}: {
    book: Book;
    setActiveSnipId?: Dispatch<number>;
}) {
    // Keep track of uploads and errors
    const [progress, setProgress] = useState(null);
    const [error, setError] = useState<string | null>(null);

    const onLoad = useCallback(
        (snip_ids: number | number[]) => {
            // Set first active snip
            if (snip_ids instanceof Array) {
                setActiveSnipId && setActiveSnipId(snip_ids[0]);
            } else {
                setActiveSnipId && setActiveSnipId(snip_ids);
            }
            setProgress(null);
        },
        [setActiveSnipId]
    );

    // Send file to server with xmlHttpRequest
    const onDrop = useCallback(
        (acceptedFiles, fileRejections) => {
            // Do something with the files
            if (fileRejections.length > 0) {
                setError(fileRejections[0].errors[0].message);
                setTimeout(() => {
                    setError(null);
                }, 6000);
            } else {
                uploadFiles(book.id, acceptedFiles, onLoad, setProgress);
            }
        },
        [book.id, onLoad]
    );

    // Configure dropzone
    const { getRootProps, getInputProps, isDragActive } = useDropzone({
        onDrop,
        accept: {
            "image/*": [".jpeg", ".png"],
            "text/*": [".txt"],
        },
        multiple: true,
    });

    return (
        <div {...getRootProps()} className={styles.uploadForm}>
            <div className={styles.wrapper}>
                <input {...getInputProps()} />
                <div className="p-2">
                    {isDragActive ? (
                        <div>Drop here! </div>
                    ) : (
                        <div>
                            Drag &apos;n&apos; drop files here, or click to
                            select files
                        </div>
                    )}
                </div>
                {error ? (
                    <div className="alert alert-danger">{error}</div>
                ) : null}
                <i
                    className="bi bi-image p-2"
                    style={{ fontSize: "2.5rem", marginTop: "-0.5rem" }}
                ></i>
                {progress ? (
                    <ProgressBar
                        variant="primary"
                        now={progress}
                        label={`${progress.toFixed(2)}%`}
                    />
                ) : null}
            </div>
        </div>
    );
}

function uploadFiles(
    book_id: number,
    files: FileList,
    onLoad?: (snip_id: number | number[]) => void,
    onProgress?: (progress: number) => void
): XMLHttpRequest {
    // create new XMLHttpRequest and add event listeners
    const req = new XMLHttpRequest();
    req.open("POST", `/api/books/${book_id}/upload`);
    req.addEventListener("load", () => {
        const snip_ids = JSON.parse(req.response)["ids"];
        onLoad && onLoad(snip_ids);
    });
    req.upload.addEventListener("progress", (e: ProgressEvent) => {
        onProgress && onProgress((e.loaded / e.total) * 100);
    });

    // create form data and append files
    const form = new FormData();
    for (let file = 0; file < files.length; file++) {
        form.append("file" + file, files[file], files[file].name);
    }
    form.append("book_id", String(book_id));

    // send post request see api/book/id/upload
    req.send(form);
    return req;
}
