import { Context } from "react";

import {
    DoodleTool,
    DoodleToolContext,
    DoodleToolContextProvider,
} from "./doodle.tool";
import {
    InteractionTool,
    InteractionToolContext,
    InteractionToolContextProvider,
} from "./interaction.tool";
import {
    MovePageTool,
    MovePageToolContext,
    MovePageToolContextProvider,
} from "./movePage.tool";
import {
    SnipEditorTool,
    SnipEditorToolContext,
    SnipEditorToolContextProvider,
} from "./snipEditor.tool";
import {
    TextTool,
    TextToolContext,
    TextToolContextProvider,
} from "./text.tool";
import { Tool, ToolComponents, ToolContext } from "./typing";

export function getProvider(tool: Tool) {
    switch (tool) {
        case "movePage":
            return MovePageToolContextProvider;
        case "doodle":
            return DoodleToolContextProvider;
        case "snipEditor":
            return SnipEditorToolContextProvider;
        case "text":
            return TextToolContextProvider;
        default:
            console.log("Interactions context provider tool");
            return InteractionToolContextProvider;
    }
}

export function getContext(tool: Tool): Context<ToolContext> {
    switch (tool) {
        case "movePage":
            return MovePageToolContext;
        case "doodle":
            return DoodleToolContext;
        case "snipEditor":
            return SnipEditorToolContext;
        case "text":
            return TextToolContext;
        default:
            // By default we pass the interaction tool context
            return InteractionToolContext;
    }
}

export function getToolComponents(tool: Tool): ToolComponents {
    switch (tool) {
        case "movePage":
            return MovePageTool;
        case "doodle":
            return DoodleTool;
        case "snipEditor":
            return SnipEditorTool;
        case "text":
            return TextTool;
        default:
            // Has no components
            return InteractionTool;
    }
}
