/** Handle response data from worker
 *
 * This can be a variety of different things, depending on the type of event
 * please see the InteractionEventMap for more information. You can also
 * add your own events there.
 */

import { BaseSnip, EventContext } from "snips/general/base";
import { get_snip_from_data } from "snips/get_snip_from_data";

import {
    InteractionEventResponseData,
    InteractionEventResponseMap,
} from "components/viewer/worker/pageWorker/interactionEvents";

// eslint-disable-next-line @typescript-eslint/no-unused-vars
function log(...x: unknown[]) {
    console.log("[interaction.tool handle_response]", x);
}

export function get_response_handlers<
    K extends keyof InteractionEventResponseMap
>(
    responses: InteractionEventResponseData<K>[]
): ((context: EventContext) => void)[] {
    if (responses.length == 0) return;

    const handlers: ((context: EventContext) => void)[] = [];
    for (const response of responses) {
        const handler = get_response_handler(response);
        if (handler) handlers.push(handler);
    }

    //Remove undefined handlers
    return handlers;
}

export function get_response_handler<
    K extends keyof InteractionEventResponseMap
>(response: InteractionEventResponseData<K>) {
    if (!response) return;
    console.log("handle_response", response);

    // Every fully defined event should have a snip
    let snip: BaseSnip;
    if (response.data) {
        snip = get_snip_from_data(response.data);
    } else {
        return;
    }
    if (typeof snip[response.type] === "function") {
        return snip[response.type];
    }
}
