import { useContext, useRef } from "react";

import { MovePageToolContext } from "../movePage.tool";

import { PagesContext } from "components/viewer/page";

import styles from "../doodle/styles.module.scss";

/** SubMenu for the tool
 * Only shows current zoom level and two
 * buttons to center and fit the page
 *
 * Zoom level is always dependent on the
 * screen size and the page size i.e.
 * zoom = pageHeight / screenHeight
 */
export function SubMenu() {
    const rangeInputRef = useRef<HTMLInputElement>(null);
    const numberInputRef = useRef<HTMLInputElement>(null);
    const { numPages } = useContext(PagesContext);
    const { fitPage, centerPage, zoom, setZoom } =
        useContext(MovePageToolContext);

    return (
        <>
            {Array(numPages)
                .fill(0)
                .map((_, idx) => {
                    return (
                        <div key={idx + "submenu"} className={styles.submenu}>
                            <div
                                key={idx + "zoom"}
                                className={styles.zoomSelector}
                            >
                                <label>Zoom</label>
                                <div className="range-container">
                                    <input
                                        ref={rangeInputRef}
                                        type="range"
                                        min={0.25}
                                        max={4}
                                        step={0.05}
                                        value={zoom[idx] || 1}
                                        onChange={(e) => {
                                            let current_val = (
                                                e.target as HTMLInputElement
                                            ).valueAsNumber;

                                            // Disallow very small zooms
                                            // as they break the view matrix
                                            if (current_val < 0.25) {
                                                current_val = 0.25;
                                            }

                                            numberInputRef.current.value =
                                                String(current_val);
                                            setZoom(current_val, idx);
                                        }}
                                    />
                                </div>
                                <div className="number-container">
                                    <button
                                        className="input-group-text"
                                        onClick={() => {
                                            setZoom(1, idx);
                                        }}
                                    >
                                        <i className="bi bi-arrow-counterclockwise"></i>
                                    </button>
                                    <input
                                        ref={numberInputRef}
                                        type="number"
                                        min={0.25}
                                        max={4}
                                        step={0.05}
                                        value={zoom[idx] || 1}
                                        onInput={(e) => {
                                            let current_val = (
                                                e.target as HTMLInputElement
                                            ).valueAsNumber;

                                            // Disallow very small zooms
                                            // as they break the view matrix
                                            if (current_val < 0.25) {
                                                current_val = 0.25;
                                            }

                                            setZoom(current_val, idx);
                                        }}
                                    />
                                </div>
                            </div>
                            <div
                                key={idx + "btn"}
                                className="btn-group"
                                role="group"
                                aria-label="Basic example"
                            >
                                <button
                                    type="button"
                                    className="btn"
                                    onClick={() => centerPage(idx)}
                                >
                                    Center
                                </button>
                                <button
                                    type="button"
                                    className="btn"
                                    onClick={() => fitPage(idx)}
                                >
                                    Fit
                                </button>
                            </div>
                        </div>
                    );
                })}
        </>
    );
}
