import { useContext } from "react";

import { SnipEditorToolContext } from "../snipEditor.tool";

import { ImageSnip } from "snips/general/image";

import { PagesContext } from "components/viewer/page";
import { SidebarContext } from "components/viewer/sidebar";

import styles from "../../toolbar/toolbar.module.scss";

export default function Button() {
    const { workers } = useContext(PagesContext);

    const { active, activeSubMenu } = useContext(SnipEditorToolContext);

    const { activeSnip } = useContext(SidebarContext);

    const onClickPlace = () => {
        if (activeSnip) {
            workers[0].placeOnPage(activeSnip.to_data());
        }
    };

    /** Depending on the type of the snip we show different tools
     * For now we only have image snips here but we might add more
     */
    let content = null;
    if (activeSnip instanceof ImageSnip) {
        content = <ImageSnipEdiorBtns />;
    }

    if (!workers || workers.length === 0) {
        return null;
    }

    // The snip editor tool works a bit different as it is effectively a toolbar
    // Here we can change the subtool by clicking on the corresponding btn
    // If the tool is not active it is not visible
    return (
        <>
            <div
                className={styles.toolBtnGroup}
                data-active={active}
                data-submenu={activeSubMenu}
            >
                {content}
            </div>
            <div
                className={styles.placeBtn}
                data-active={active}
                onClick={onClickPlace}
            >
                <button className="btn btn-danger">Place on page!</button>
            </div>
        </>
    );
}

const ImageSnipEdiorBtns = () => {
    const {
        toggleSubMenu,
        activeSubTool,
        setActiveSubTool,
        activeSubSubMenu,
        setActiveSubSubMenu,
    } = useContext(SnipEditorToolContext);

    return (
        <div className={styles.toolBtn}>
            <button
                className="btn"
                onClick={setActiveSubTool.bind(null, "resize")}
                data-active={activeSubTool === "resize"}
                onContextMenu={(e) => {
                    e.preventDefault();
                    setActiveSubSubMenu("resize");
                }}
            >
                <i className="bi bi-bounding-box-circles"></i>
                <div
                    onClick={toggleSubMenu}
                    className={styles.arrow}
                    data-active={activeSubSubMenu == "resize"}
                >
                    {activeSubSubMenu == "resize" ? "<" : ">"}
                </div>
            </button>
            <button
                className="btn"
                onClick={setActiveSubTool.bind(null, "cut")}
                data-active={activeSubTool === "cut"}
                onContextMenu={(e) => {
                    e.preventDefault();
                    setActiveSubSubMenu("cut");
                }}
            >
                <i className="bi bi-scissors"></i>
                <div
                    onClick={toggleSubMenu}
                    className={styles.arrow}
                    data-active={activeSubSubMenu == "cut"}
                >
                    {activeSubSubMenu == "cut" ? "<" : ">"}
                </div>
            </button>
        </div>
    );
};
