import { useCallback, useContext } from "react";

import { TextToolContext } from "../text.tool";

import { PagesContext } from "components/viewer/page";

import styles from "../../toolbar/toolbar.module.scss";

export default function Button() {
    const { pageDataRef, workers } = useContext(PagesContext);
    const {
        active,
        toggleActive,
        toggleSubMenu,
        activeSubMenu,
        activeSnip,
        setActiveSnip,
        overlay,
    } = useContext(TextToolContext);

    const placeSnip = useCallback(() => {
        if (!activeSnip) return;

        activeSnip.page_id = pageDataRef.current.get(overlay.page_idx).id;
        workers[overlay.page_idx].insertSnip(activeSnip.to_data());
        setActiveSnip(null);
    }, [activeSnip, pageDataRef, overlay, workers, setActiveSnip]);

    return (
        <>
            <div
                className={styles.toolBtn}
                data-active={active}
                data-submenu={activeSubMenu}
                onContextMenu={(e) => {
                    e.preventDefault();
                    toggleSubMenu();
                }}
            >
                <button className="btn" onClick={toggleActive}>
                    {font_svg}
                </button>
                <div
                    onClick={toggleSubMenu}
                    className={styles.arrow}
                    data-active={activeSubMenu}
                >
                    {activeSubMenu ? "<" : ">"}
                </div>
            </div>
            <div
                className={styles.placeBtn}
                data-active={active && activeSnip ? true : false}
            >
                <button className="btn btn-danger" onClick={placeSnip}>
                    Place on page!
                </button>
            </div>
        </>
    );
}

const font_svg = (
    <svg
        xmlns="http://www.w3.org/2000/svg"
        width="16"
        height="16"
        fill="currentColor"
        className="bi bi-fonts"
        viewBox="0 0 16 16"
    >
        <path d="M12.258 3h-8.51l-.083 2.46h.479c.26-1.544.758-1.783 2.693-1.845l.424-.013v7.827c0 .663-.144.82-1.3.923v.52h4.082v-.52c-1.162-.103-1.306-.26-1.306-.923V3.602l.431.013c1.934.062 2.434.301 2.693 1.846h.479L12.258 3z" />
    </svg>
);
