/** Interaction events allow to send
 * mouse events to the worker thread
 * this also allows to return
 */

import { BaseData, BaseView, SnipData } from "snips/general/base";

// We can extend this to add more functionality
// to event but for now we only need the coords
interface IBaseEvent {
    coords: [number, number];
}

interface IBaseInteraction<E> {
    event: E;
}

// These interaction events are on the level of the page
// the corresponding response events are on the level of the snip
export interface InteractionEventMap {
    pointerenter: IBaseInteraction<IBaseEvent>;
    pointerleave: IBaseInteraction<IBaseEvent>;
    pointermove: IBaseInteraction<IBaseEvent>;
    pointerdown: IBaseInteraction<IBaseEvent>;
    dblclick: IBaseInteraction<IBaseEvent>;
}

// These interaction events are on the level of the snip
// i.e. if the snip is clicked on
export interface InteractionEventResponseMap {
    //This is called when the snip is clicked on
    on_pointerdown: IBaseInteraction<SnipData<BaseData, BaseView>>;
    //This is called when the snip is double clicked on
    on_dblclick: IBaseInteraction<SnipData<BaseData, BaseView>>;
    //This is called when the mouse enters the snip
    on_pointerenter: IBaseInteraction<SnipData<BaseData, BaseView>>;
    //This is called when the mouse leaves the snip
    on_pointerleave: IBaseInteraction<SnipData<BaseData, BaseView>>;
    // FYI: enter and leave can be used to implement hover
}

/** Data used for sending interaction events */
export interface InteractionEventData<K extends keyof InteractionEventMap> {
    type: K;
    data: InteractionEventMap[K]["event"];
}

/** Data used for sending interaction events (response)*/
export interface InteractionEventResponseData<
    K extends keyof InteractionEventResponseMap
> {
    type: K;
    data: InteractionEventResponseMap[K]["event"];
}
