import {
    InteractionEventData,
    InteractionEventMap,
    InteractionEventResponseData,
    InteractionEventResponseMap,
} from "./interactionEvents";

import type { PageData } from "controller/page";
import type { BaseData, BaseView, SnipData } from "snips/general/base";

export interface MessageMap {
    /** Init message send to initialize worker and
     * transfers the offscreen canvas.
     */
    init: {
        canvas: OffscreenCanvas;
        url_params: string;
    };

    /** Shutdown message send to termination worker */
    shutdown: void;

    /** Setup the page to render
     * sends the serialized page.
     **/
    setupPage: {
        page: PageData;
    };

    /** Add a snip to the currently active page
     * sends the serialized snip.
     * */
    placeOnPage: {
        snip: SnipData<BaseData, BaseView>;
    };

    /** Insert a snip to the currently active page
     * sends the serialized snip. (not placed)
     * */
    insertSnip: {
        snip: SnipData<BaseData, BaseView>;
    };

    /** Render the page */
    render: void;

    /** Resize the canvas */
    resize: {
        width: number;
        height: number;
    };

    interactionEvent: {
        event: InteractionEventData<keyof InteractionEventMap>;
    };
}

// Messages from main to worker
export interface Message<K extends keyof MessageMap = keyof MessageMap> {
    type: K;
    event_id: number;
    data: MessageMap[K];
}

export interface ResponseMap<
    T extends keyof InteractionEventResponseMap = keyof InteractionEventResponseMap
> {
    init: void;
    shutdown: void;
    setupPage: void;
    placeOnPage: void;
    insertSnip: void;
    render: void;
    resize: void;
    interactionEvent: InteractionEventResponseData<T>[];
}

export interface Response<
    K extends keyof ResponseMap = keyof ResponseMap,
    T extends keyof InteractionEventResponseMap = keyof InteractionEventResponseMap
> {
    type: K;
    event_id: number;
    response: ResponseMap<T>[K];
}
