/* This file loads environment variables from .env file
 * and makes them available to the rest of the app. Please
 * use the .env file to configure your app.
 */

// Check if running in browser
if (typeof window !== "undefined") {
    throw new Error(
        "This file should not be loaded in the browser. SECURITY RISK!"
    );
}


export const config = {
    /** Defines the source folder in the docker container */
    SRC_FOLDER: "/usr/src/app",
    /** Is set by the startup of the server */
    NODE_ENV: process.env.NODE_ENV || "development",
    /** The port the server is running on */
    PORT: parseInt(process.env.PORT || "4000"),
    /** The host the server is running on */
    HOSTNAME: process.env.HOSTNAME || "localhost",

    MAINTENANCE: process.env.MAINTENANCE || "false",

    /** Everything database related i.e. mariadb/mysql */
    MYSQL: {
        /** The host of the mysql server */
        HOST: process.env.MYSQL_HOST || "localhost",
        /** The port of the mysql server */
        PORT: parseInt(process.env.MYSQL_PORT || "3306"),
        /** The user of the mysql server */
        USER: process.env.MYSQL_USER || "snip",
        /** The password of the mysql server */
        PASSWORD:
            process.env.MYSQL_PASSWORD || "well_this_should_be_changed_as_well",
    },

    /** Everything regarding email verification */
    EMAIL: {
        /** The host of the email server */
        HOST: process.env.EMAIL_HOST || "email.gwdg.de",
        /** The port of the email server */
        PORT: parseInt(process.env.EMAIL_PORT || "587"),
        /** The user of the email server */
        USER: process.env.EMAIL_USER || "",
        /** The password of the email server */
        PASSWORD: process.env.EMAIL_PASSWORD || "",
        /** The secret key which is used for the tokens */
        TOKEN_SECRET:
            process.env.EMAIL_TOKEN_SECRET ||
            "keyboard_cat_at_least_32_chars_long",
    },
    /** Secret used to hash the api tokens */
    API_TOKEN_SECRET:
        process.env.API_TOKEN_SECRET || "keyboard_cat_at_least_32_chars_long",
    /** Secret used to encryption/decryption session cookies */
    SESSION_SECRET:
        process.env.SESSION_SECRET || "keyboard_cat_at_least_32_chars_long",
    /** Secret used for initial verification of socket connection */
    SOCKET_SECRET:
        process.env.SOCKET_SECRET || "keyboard_cat_at_least_32_chars_long",
    /** Number of render workers */
    NUM_RENDER_PROCESSES: process.env.NUM_RENDER_PROCESSES || "4",
};
