import { cm2px } from "./utils";

/** Renders a checkered background onto a canvas given a
 * ctx.
 *
 * @param ctx The canvas context to render onto.
 * @param width The width of a box in mm
 * @param height The height of a box in mm.
 *
 */
export function render_checkered(
    ctx: CanvasRenderingContext2D | OffscreenCanvasRenderingContext2D,
    lwidth = 4,
    lheight = 4
) {
    // Scale to db coordinates
    const max_db = [1400, 2000];
    const scale = max_db[1] / max_db[0];

    const delta_x = cm2px(lwidth / 10) * scale;
    const delta_y = cm2px(lheight / 10) * scale;
    const padding_x = (delta_x / 2) * scale;
    const padding_y = (delta_y / 2) * scale;

    ctx.strokeStyle = "#d3d3d3"; // Light grey
    ctx.lineWidth = 1;

    // Convert to canvas transform
    const transform = ctx.getTransform().invertSelf();
    const width =
        transform.a * ctx.canvas.width +
        transform.b * ctx.canvas.height +
        transform.e;
    const height =
        transform.c * ctx.canvas.width +
        transform.d * ctx.canvas.height +
        transform.f;

    //Determine how many boxes can fit on the canvas
    const num_vertical = Math.floor((width - padding_x) / delta_x);
    const num_horizontal = Math.floor((height - padding_y) / delta_y);

    // Calc starting point such that it is centered
    const start_x = (width - num_vertical * delta_x) / 2;
    const start_y = (height - num_horizontal * delta_y) / 2;

    // Draw vertical lines
    for (let i = 0; i < num_vertical + 1; i++) {
        ctx.beginPath();
        ctx.moveTo(start_x + i * delta_x, start_y);
        ctx.lineTo(start_x + i * delta_x, height - start_y);
        ctx.stroke();
    }

    // Draw horizontal lines
    for (let i = 0; i < num_horizontal + 1; i++) {
        ctx.beginPath();
        ctx.moveTo(start_x, start_y + i * delta_y);
        ctx.lineTo(width - start_x, start_y + i * delta_y);
        ctx.stroke();
    }

    return;
}
