import { ConfigServiceInterface } from "../service.typings";
import { UserConfigData } from "../service.typings";

import { pool_permissions as pool } from "database/sql.connection";


const config_default: Required<UserConfigData> = {
    id: -1,
    last_updated: new Date(),
    pen_color: "#000000",
    pen_size: 4,
    pen_smoothing: 0.0,
    text_font_id: 1,
    text_font: "Arial",
    text_fontColor: "#000000",
    text_fontSize: 12,
    text_lineHeight: 1.25,
    text_lineWrap: 400,
    user_id: -1,
    zoom1: 1,
    zoom2: 1,
}


async function getByUserId(user_id: number): Promise<UserConfigData> {

    if (!user_id || user_id === -1) {
        return config_default;
    }
    const sql = "SELECT * FROM user_config_resolved WHERE user_id = ?";
    const configData: UserConfigData = await pool.query<UserConfigData[]>(sql, [user_id])
        .then((res) => {
            if (res.length != 1) {
                throw new Error("Config not found for user_id:" + user_id);
            }
            // As the database structure matches our UserConfigData interface
            return res[0];
        })
        .catch((err) => {
            console.error(err);
            return config_default;
        });

    return configData;
}


async function updateByUserId(user_id: number, configUpd: Partial<UserConfigData>): Promise<boolean> {
    const updateValues = Object.values(configUpd);
    updateValues.push(user_id);
    const updateColumns = Object.keys(configUpd).map((key) => `${key} = ?`).join(', ');
    const sql = `UPDATE user_config SET ${updateColumns} WHERE user_id = ?`;

    const configData = await pool.query(sql, updateValues).then((res) => {
        if (res.affectedRows != 1) {
            throw new Error("Config not found for user_id:" + user_id);
        }
        return true;
    });
    return configData;
}




/** Check typing */
const ConfigService: ConfigServiceInterface = {
    getByUserId,
    updateByUserId,
};
export default ConfigService;
