import { config } from "config";
import { registerService } from "lib/registerService";
import mariadb from "mariadb";
import process from "node:process";

const tinyToBoolean = (column, next) => {
    if (column.type == "TINY" && column.length === 1) {
        const val = column.int();
        return val === null ? null : val === 1;
    }
    return next();
};

const pool_data: mariadb.Pool = registerService("pool_data", () => {
    return mariadb.createPool({
        host: config.MYSQL.HOST,
        user: config.MYSQL.USER,
        password: config.MYSQL.PASSWORD,
        database: "snip_data",
        dateStrings: true,
        connectionLimit: 5,
        trace: config.NODE_ENV === "development", // Enable tracing for development
        bigIntAsNumber: true,
        decimalAsNumber: true,
        insertIdAsNumber: true,
        typeCast: tinyToBoolean,
    });
});

pool_data
    .getConnection()
    .then((conn) => {
        conn.ping();
        console.debug(
            "[Database][snip_data] Connection established (PID:" +
                process.pid +
                ")"
        );
        conn.release();
    })
    .catch((err) => {
        console.error(err); // any of connection time or query time errors from above
    });

const pool_permissions: mariadb.Pool = registerService("pool_perms", () => {
    return mariadb.createPool({
        host: config.MYSQL.HOST,
        user: config.MYSQL.USER,
        password: config.MYSQL.PASSWORD,
        database: "snip_perms",
        dateStrings: true,
        connectionLimit: 5,
        trace: config.NODE_ENV === "development", // Enable tracing for development
        bigIntAsNumber: true,
        decimalAsNumber: true,
        insertIdAsNumber: true,
        typeCast: tinyToBoolean,
    });
});

pool_permissions
    .getConnection()
    .then((conn) => {
        conn.ping();
        console.debug(
            "[Database][snip_perms] Connection established (PID:" +
                process.pid +
                ")"
        );
        conn.release();
    })
    .catch((err) => {
        console.error(err); // any of connection time or query time errors from above
    });

export { pool_data, pool_permissions };
