import { config } from "config";
import fs from "fs";
import { sign } from "jsonwebtoken";
import { createTransport } from "nodemailer";
import Mail from "nodemailer/lib/mailer";
import path from "path";

function send_pw_reset_email(email, pw_hash) {
    const data = {
        time: Date(),
        email: email,
        type: "pw_reset",
    };
    // i. Create token
    const token = sign(data, config.EMAIL.TOKEN_SECRET + pw_hash);

    //ii. Send email
    const transporter = createTransport({
        host: config.EMAIL.HOST,
        port: config.EMAIL.PORT,
        auth: {
            user: config.EMAIL.USER,
            pass: config.EMAIL.PASSWORD,
        },
    });
    const mailOptions = get_email_content(token, email);
    transporter.sendMail(mailOptions, (error, info) => {
        if (error) {
            console.error(error);
        } else {
            console.log("Email sent: " + info.response);
        }
    });
}

function get_email_content(token, to_email): Mail.Options {
    const reset_link =
        "https://snip.roentgen.physik.uni-goettingen.de/account/resetPassword?token=" +
        token +
        "&email=" +
        to_email;

    // Get email template
    const email = fs.readFileSync(
        path.resolve(__dirname, "./pw_reset.html"),
        "utf8"
    );

    // Replace placeholders
    const email_html = email.replaceAll("{{resetLink}}", reset_link);

    return {
        from: `SNIP Team <${config.EMAIL.USER}>`,
        to: to_email,
        subject: "SNIP - Password reset",
        html: email_html,
    };
}

//Get arguments from command line
const args = process.argv.slice(2);
const email = args[0];
const pw_hash = args[1];
send_pw_reset_email(email, pw_hash);
