import { config } from "config";
import fs from "fs";
import { sign } from "jsonwebtoken";
import { createTransport } from "nodemailer";
import Mail from "nodemailer/lib/mailer";
import path from "path";

function send_verify_email(email: string) {
    const data = {
        time: Date(),
        email: email,
    };
    // i. Create token
    const token = sign(data, config.EMAIL.TOKEN_SECRET);

    //ii. Send email
    const transporter = createTransport({
        host: config.EMAIL.HOST,
        port: config.EMAIL.PORT,
        auth: {
            user: config.EMAIL.USER,
            pass: config.EMAIL.PASSWORD,
        },
    });
    const mailOptions = get_email_content(token, email);
    transporter.sendMail(mailOptions, (error, info) => {
        if (error) {
            console.error(error);
        } else {
            console.log("Email sent: " + info.response);
        }
    });
    // iii. see api/authentication/verify.ts for next steps
}

function get_email_content(token: string, to_email: string): Mail.Options {
    const verify_link =
        "https://snip.roentgen.physik.uni-goettingen.de/account/verify?token=" + token;
    const user_email = to_email;
    const raw_link = "https://snip.roentgen.physik.uni-goettingen.de/account/verify";

    // Get email template
    const email = fs.readFileSync(
        path.resolve(__dirname, "./verify_me.html"),
        "utf8"
    );
    // Replace placeholders
    const email_html = email
        .replaceAll("{{verify_link}}", verify_link)
        .replaceAll("{{user_email}}", user_email)
        .replaceAll("{{raw_link}}", raw_link)
        .replaceAll("{{token}}", token);

    return {
        from: `SNIP Team <${config.EMAIL.USER}>`,
        to: to_email,
        subject: "Welcome to SNIP - Please verify your email",
        html: email_html,
    };
}

//Get arguments from command line
const args = process.argv.slice(2);
const email = args[0];
send_verify_email(email);
