import { useRouter } from "next/router";
import useSWR from "swr";

import { fetcher } from "./fetcher";

import { Book, BookData } from "controller/book";

/** Get all available books for a user
 *
 */
export default function useBooks() {
    const {
        data: booksData,
        mutate: mutateBooks,
        error,
    } = useSWR<BookData[]>("/api/books", fetcher, {
        revalidateIfStale: false,
        revalidateOnFocus: false,
        revalidateOnReconnect: false,
    });

    //Transform bookData to books
    let books: Book[] = [];
    if (booksData) {
        books = booksData.map((bookData) => {
            return Book.from_data(bookData);
        });
    }
    return {
        books: books,
        isLoading: !error && !books,
        isError: error,
        mutateBooks,
    };
}

/* Determine current book by router */
export function CurrentBookID() {
    const router = useRouter();
    const { id } = router.query;
    return id ? Number(id) : null;
}
