// eslint-disable-next-line @typescript-eslint/no-var-requires
const { PHASE_DEVELOPMENT_SERVER } = require('next/constants');
const withBundleAnalyzer = require("@next/bundle-analyzer")({
    enabled: process.env.ANALYZE === "true",
});


const filter_client = (resource, context) => {
    switch (resource) {
        case "sharp":
        case "canvas":
            console.log("Ignoring module (client-side): " + resource);
            return true;
        default:
            return false;
    }
};



module.exports = (phase,) => {
    const CONFIG_SHARED = {
        poweredByHeader: false,
        eslint: {
            dirs: [
                "lib",
                "socket",
                "database",
                "components",
                "pages",
                "snips",
                "controller",
            ],
        },
        webpack: (config, { isServer, webpack }) => {
            // Fixes npm packages that depend on `fs` module
            if (!isServer) {
                // fs and path
                config.plugins.push(new webpack.IgnorePlugin({ checkResource: filter_client }));
                config.resolve.fallback = {
                    fs: false,
                    path: false,
                }
            }
            return config;
        },
        async redirects() {
            if (process.env.MAINTENANCE === "true") {
                console.log("MAINTENANCE MODE");
                return [
                    {
                        source: "/((?!maintenance).*)",
                        destination: "/maintenance.html",
                        permanent: false, //!!!IMPORTANT!!!
                    },
                ];
            } else {
                return [
                    {
                        source: "/maintenance.html",
                        destination: "/",
                        permanent: false,
                    },
                    {
                        source: "/:path*.(md|mdx)",
                        destination: "/:path*",
                        permanent: false,
                    },
                ];
            }
        },
    }


    if (phase === PHASE_DEVELOPMENT_SERVER) {
        return withBundleAnalyzer({
            /* development only config options here */
            ...CONFIG_SHARED,
        })
    }

    return {
        /* config options for all phases except development here */
        ...CONFIG_SHARED,
        compress: true,
        swcMinify: true,
        compiler: {
            removeConsole: {
                exclude: ['error'],
            },
        },
    }
}

