import { get_browser, isSupported } from "lib/browserSupported";
import { type NextPage } from "next";
import type { AppProps } from "next/app";
import Head from "next/head";
import { type ReactElement, type ReactNode, useEffect } from "react";

import { DefaultLayout } from "components/common";

import "bootstrap-icons/font/bootstrap-icons.scss";
import "components/styles/bootstrap.scss";
import "components/styles/global.scss";

/** Disable console debug statements in
 * production environment
 */
if (process.env.NODE_ENV !== "development") {
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    console.debug = () => {};
}

export type NextPageWithLayout<P = object, IP = P> = NextPage<P, IP> & {
    getLayout?: (page: ReactElement) => ReactNode;
};
type AppPropsWithLayout = AppProps & {
    Component: NextPageWithLayout;
};

export default function MyApp({ Component, pageProps }: AppPropsWithLayout) {
    useEffect(() => {
        typeof document !== "undefined"
            ? require("bootstrap/dist/js/bootstrap")
            : null;
    }, []);

    //Check if browser is supported
    useEffect(() => {
        if (typeof window !== "undefined") {
            if (!isSupported(get_browser())) {
                alert(
                    "Your browser might not be supported. Please use Chrome>69, Firefox>105, Safari>16.4, Opera>48 or Edge>79."
                );
            }
        }
    }, []);

    /** Get layout from page if defines */
    const getLayout =
        Component.getLayout ??
        ((page: ReactElement) => {
            const title = page.props.title;
            return <DefaultLayout title={title}>{page}</DefaultLayout>;
        });
    return (
        <>
            <Head>
                <title>Snip</title>
                <meta
                    name="viewport"
                    content="width=device-width, initial-scale=1"
                />
            </Head>

            {getLayout(<Component {...pageProps} />)}
        </>
    );
}
