import Link from "next/link";
import { useState } from "react";

import { getLayout } from "./login";

import { EmailInput } from "components/forms/Form";
import { validateEmail } from "components/forms/validation";

import styles from "components/forms/Form.module.scss";

export default function ForgotPassword() {
    const [email, setEmail] = useState("");
    const [success, setSuccess] = useState(false);
    const [error, setError] = useState("");

    const handleSubmit = async (event) => {
        event.preventDefault();

        const response = await fetch("/api/account/resetPassword", {
            method: "POST",
            headers: {
                "Content-Type": "application/json",
            },
            body: JSON.stringify({
                email,
            }),
        }).then((res) => res.json());

        if (response.success) {
            setSuccess(true);
            setEmail("");
        } else {
            setError("Could not reset email, does the email exist?");
        }
    };

    const email_valid = validateEmail(email);

    if (success) {
        return (
            <div className={styles.form}>
                <div className={styles.header}>
                    An email has been sent to {email} with instructions on how
                    to reset your password.
                </div>
            </div>
        );
    }

    return (
        <div className="w-100 h-100 d-flex justify-content-center align-items-center">
            <div className={styles.form}>
                {error && (
                    <div
                        className="mb-2  text-center"
                        style={{ fontSize: "1.2rem", fontWeight: "bold" }}
                    >
                        {error}
                        <hr />
                    </div>
                )}
                <form onSubmit={handleSubmit}>
                    <fieldset>
                        <div className={styles.header}>Reset your password</div>

                        <EmailInput
                            isValid={email_valid}
                            isInvalid={!email_valid}
                            invalidFeedback="Not a valid email address."
                            onInput={(e) => setEmail(e.target.value)}
                        />

                        <div className="d-flex align-items-center text-center flex-column">
                            <button
                                className="btn btn-primary btn-block fa-lg gradient-custom-2 mb-2"
                                style={{ width: "90%" }}
                                type="submit"
                            >
                                Submit
                            </button>
                            <Link
                                className="text-muted text-center"
                                href="/account/login"
                            >
                                Back to login
                            </Link>
                        </div>
                    </fieldset>
                </form>
            </div>
        </div>
    );
}
ForgotPassword.getLayout = getLayout;
