import useUser from "lib/useUser";
import { withSessionSsr } from "lib/withSession";

import { DefaultLayoutWithSidebar } from "components/common/DefaultLayout";
import PrettyPrintJson from "components/utils/PrettyPrintJson";

export default function Account() {
    const { user, isLoadingUser, config } = useUser();

    // Fetch the user client side

    if (isLoadingUser) {
        return (
            <>
                <div>Loading...</div>
            </>
        );
    }

    return (
        <>
            <PrettyPrintJson user={user} config={config} />
        </>
    );
}

Account.getLayout = function getLayout(page) {
    const title = "My Account";
    return (
        <DefaultLayoutWithSidebar title={title}>
            {page}
        </DefaultLayoutWithSidebar>
    );
};

/** Middleware for authentication
 * redirects to login page if user is not logged in
 *
 * This runs before the page is rendered
 */
export const getServerSideProps = withSessionSsr(
    async function getServerSideProps({ req, resolvedUrl }) {
        // Check Session
        const user_id = req.session.user_id;
        if (user_id) {
            return {
                props: {
                    user_id,
                },
            };
        }

        return {
            redirect: {
                permanent: false,
                destination: `/login?redirect=${resolvedUrl}`,
            },
        };
    }
);
