import { withSessionSsr } from "lib/withSession";
import { useRouter } from "next/router";
import { useEffect, useState } from "react";

import { verify_token } from "../api/authentication/verify";
import { getLayout } from "./login";

import { VerifyForm } from "components/forms/VerifyForm";

export default function Verify(props) {
    const [success, setSuccess] = useState<boolean>(false);
    const router = useRouter();

    // Parse props
    useEffect(() => {
        if (props.success) {
            setSuccess(props.success);
        }
    }, [props]);

    return (
        <>
            {success ? (
                <div className="d-flex align-items-center text-center flex-column mt-3">
                    <div className="alert alert-success d-flex" role="alert">
                        <strong>Email verification successful!</strong>
                    </div>
                    <button
                        className="btn btn-primary btn-block fa-lg gradient-custom-2 "
                        style={{ width: "90%" }}
                        onClick={() => {
                            router.push("/");
                        }}
                    >
                        Login
                    </button>
                </div>
            ) : (
                <VerifyForm
                    onSuccess={() => setSuccess(true)}
                    link_error={props.error}
                />
            )}
        </>
    );
}

Verify.getLayout = getLayout;

//Check for the token in the url and verify it if supplied
export const getServerSideProps = withSessionSsr(
    async function getServerSideProps(context) {
        const { query, req } = context;
        if (query.token) {
            const payload = await verify_token(query.token as string);
            // Update session cookie if token is valid
            if (payload.success && req.session.user_id) {
                req.session.email_verified = true;
                await req.session.save();
            }
            return { props: payload };
        }
        return { props: {} };
    }
);
