import { withSessionRoute } from "lib/withSession";
import { NextApiRequest, NextApiResponse } from "next/types";

import { ApiError, service } from "../_service";

import { UserData } from "database/services/service.typings";

export default withSessionRoute(loginRoute);

/* Perform post request to login user
 */
async function loginRoute(
    req: NextApiRequest,
    res: NextApiResponse<UserData | ApiError>
) {
    const { email, password } = await req.body;

    const success = await service.user.login(email, password);
    const userData = await service.user.getByEmail(email);

    if (success && userData) {
        req.session.user_id = userData.id;
        req.session.email_verified = userData.emailValidated;
        req.session.is_admin = await service.user.isAdmin(userData.id);

        await req.session.save();
        res.json(userData);
    } else {
        res.status(403).json({
            error: "Invalid email or password",
        });
    }
}
