import { execFile } from "child_process";
import { withSessionRoute } from "lib/withSession";
import { NextApiRequest, NextApiResponse } from "next/types";

import { ApiError, service } from "../_service";

import { UserData } from "database/services/service.typings";

import { Validation } from "components/forms/SignupForm";
import { validateEmail, validatePW } from "components/forms/validation";

export default withSessionRoute(signupRoute);

/* Perform post request to login user
 */
async function signupRoute(
    req: NextApiRequest,
    res: NextApiResponse<UserData | Partial<Validation> | ApiError>
) {
    // Check if post request
    if (req.method !== "POST") {
        res.status(405).json({ error: "Method not allowed" });
        return;
    }

    const { email, password } = await req.body;

    if (!email || !password) {
        res.status(400).json({
            error: "Bad Request",
            details: "Email and password are required",
        });
        return;
    }

    // Validate email and password format
    const email_valid = validateEmail(email);
    const pw_valid = validatePW(password);
    if (!email_valid || !pw_valid) {
        const valid: Partial<Validation> = {
            email: email_valid ? "valid" : "invalid",
            password: pw_valid ? "valid" : "invalid",
        };
        res.status(400).json(valid);
        return;
    }

    // Try to create user in db
    const success = await service.user.signup(email, password);
    if (success) {
        const user = await service.user.getByEmail(email);
        //login user
        req.session.user_id = user.id;
        req.session.email_verified = user.emailValidated;
        req.session.is_admin = await service.user.isAdmin(user.id);
        await req.session.save();

        // Send verify email i.e. on a new process to not block the request
        send_verify_email_from_child_process(user.email);

        res.json(user);
    } else {
        res.status(400).json({
            error: "Bad Request",
        });
        return;
    }

    // ii. Save token in db
    // iii. Send email

    // iv. see verify.ts for next steps
}

export function send_verify_email_from_child_process(email: string) {
    const filename = "lib/email/send_verify_email.ts";
    // Execute with ts-node
    execFile("ts-node", [filename, email], { cwd: "app/" }, (err, stdout) => {
        if (err) {
            console.error(err);
            return;
        }
        console.log(stdout);
    });
}
