import { NextApiRequest, NextApiResponse } from "next/types";
import { ApiError, service } from "pages/api/_service";
import { page_preview } from "socket/page/preview";


export default async function rerenderPreviews(
    req: NextApiRequest,
    res: NextApiResponse<ApiError | { success: true }>
) {
    if (req.method != "POST") {
        res.status(405).json({ error: "Method not allowed" });
        return;
    }
    const { book_id } = req.body;
    if (!book_id) {
        res.status(400).json({
            error: "Bad Request",
            details: "Missing parameter book_id!",
        });
        return;
    }



    //Fetch the book
    const book_data = await service.book.getById(Number(book_id));
    if (book_data.id == -1) {
        res.status(404).json({ error: "Book not found" });
        return;
    }

    //Fetch all pages and render preview

    const pages = await service.page.getByBookId(Number(book_id));

    const promises = [];
    for (const page of pages) {
        promises.push(page_preview(page.id, Number(book_id), true));
    }

    await Promise.all(promises).catch(() => {
        res.status(500).json({ error: "Internal Server Error" });
        return;
    });

    res.status(200).json({ success: true });
}