import { NextApiRequest, NextApiResponse } from "next/types";

import { ApiError } from "../_service";

import { pool_permissions } from "database/sql.connection";

import { UsersGroups } from "components/admin_panel/utils";

export default async function users_groups(
    req: NextApiRequest,
    res: NextApiResponse<UsersGroups | ApiError>
) {
    if (req.method !== "POST") {
        res.status(405).json({
            error: "Method Not Allowed",
            details: "Only POST requests are allowed!",
        });
        return;
    }
    const { group_ids, user_ids } = req.body;
    if (
        !group_ids ||
        !user_ids ||
        !Array.isArray(group_ids) ||
        !Array.isArray(user_ids) ||
        group_ids.length < 1 ||
        user_ids.length < 1
    ) {
        res.status(400).json({
            error: "Bad Request",
            details: "Missing parameters group_ids and/or user_ids!",
        });
        return;
    }
    const group_ids_int = group_ids.map((id) => parseInt(id));
    const user_ids_int = user_ids.map((id) => parseInt(id));
    if (
        group_ids_int.some((id) => isNaN(id)) ||
        user_ids_int.some((id) => isNaN(id))
    ) {
        res.status(400).json({
            error: "Bad Request",
            details: "group_ids and user_ids must be valid integers!",
        });
        return;
    }

    // Get all
    const sql = `
        SELECT * FROM users_groups WHERE group_id IN (${group_ids_int.join(
        ","
    )}) AND user_id IN (${user_ids_int.join(",")})
    `;
    const result = await pool_permissions
        .query(sql)
        .then((res) => {
            if (res.length < 1) {
                throw new Error("None found");
            }
            // As the database structure matches our BookData interface
            // we can just return the first row
            return res;
        })
        .catch((err) => {
            console.error(err);
            return [];
        });

    res.status(200).json(result);
}
