import { withSessionRoute } from "lib/withSession";
import { NextApiRequest, NextApiResponse } from "next";

import { ApiError, service } from "../_service";
import { send_verify_email_from_child_process } from "../account/signup";

export default withSessionRoute(resendVerifyEmailRoute);

async function resendVerifyEmailRoute(
    req: NextApiRequest,
    res: NextApiResponse<ApiError | boolean>
) {
    // Check if post request
    if (req.method !== "POST") {
        res.status(405).json({ error: "Method not allowed" });
        return;
    }

    // Get user id from session
    const { user_id, email_verified } = req.session;

    if (!user_id) {
        res.status(400).json({
            error: "Bad Request",
            details: "Login is required",
        });
        return;
    }
    if (email_verified) {
        res.status(400).json({
            error: "Bad Request",
            details: "Email already verified",
        });
        return;
    }

    // Get email from user id
    const userData = await service.user.getById(user_id);

    if (!userData.email) {
        res.status(400).json({
            error: "Bad Request",
            details: "DB error",
        });
        return;
    }

    // Send verify email i.e. on a new process to not block the request
    console.log("[Email] Swooosh");
    send_verify_email_from_child_process(userData.email);

    res.json(true);
}
