import { withSessionRoute } from "lib/withSession";
import { NextApiRequest, NextApiResponse } from "next/types";

import { ApiError } from "../_service";

import { pool_data } from "database/sql.connection";

export interface BackgroundType {
    id: number;
    name: string;
    description: string;
    created: Date;
}

export default withSessionRoute(getBackgroundTypes);

/** Gets all available background types
 *
 * This does a sql query and get the background_types table
 */
async function getBackgroundTypes(
    req: NextApiRequest,
    res: NextApiResponse<ApiError | BackgroundType[]>
) {
    const sql = "SELECT * from background_types;";

    const types = await pool_data
        .query(sql)
        .then((res) => {
            if (res.length < 1) {
                throw new Error("None found");
            }
            return res as BackgroundType[];
        })
        .catch((err) => {
            console.error(err);
            res.status(500).json({
                error: "Internal Server Error",
                details: { id: "Could not get background types" },
            });
            return [];
        });
    res.status(200).json(types);
    return;
}
