import { withSessionRoute } from "lib/withSession";
import { NextApiRequest, NextApiResponse } from "next/types";

import { ApiError } from "../_service";

import { pool_permissions } from "database/sql.connection";
import { fontsData } from "database/sql.typings";


export default withSessionRoute(fontsRoute);

/** Get a list of all available fonts with their location 
 * - This api should buffer the fonts in memory and not do 
 *  a database request every time
 * 
*/
async function fontsRoute(
    req: NextApiRequest,
    res: NextApiResponse<fontsData[] | ApiError>
) {

    const fonts = await pool_permissions.query<fontsData[]>("SELECT * FROM fonts").then((rows) => {
        return rows;
    }).catch((err) => {
        console.error(err);
        return [];
    });

    if (fonts.length > 0) {
        res.json(fonts);
    } else {
        res.json({ error: "No fonts found" });
    }
}
