import { withSessionRoute } from "lib/withSession";
import { NextApiRequest, NextApiResponse } from "next/types";

import { ApiError, service } from "../_service";

import {
    BookDataResolved,
    RESOURCE_BOOK,
} from "database/services/service.typings";

export default withSessionRoute(booksRoute);

async function booksRoute(
    req: NextApiRequest,
    res: NextApiResponse<BookDataResolved[] | ApiError>
) {
    //Get books for user
    const { books } = await getBooksByUser(req.session.user_id);
    res.json(books);
}

/** Get all books for a user with atleast pREad
 * @param user_id
 */
export async function getBooksByUser(user_id: number) {
    //Get books for user
    const acl = await service.permission.getACLByEntity(user_id);
    const books_with_pRead = acl.filter(
        (a) => a.resource_type == RESOURCE_BOOK
    );
    const book_ids = books_with_pRead.map((a) => a.resource_id);
    const books = await service.book.getByIdsResolved(book_ids);
    return { books, books_with_pRead };
}
