import { withSessionRoute } from "lib/withSession";
import type { NextApiRequest, NextApiResponse } from "next/types";

import { ApiError, service } from "../_service";

import { BookData } from "controller/book";


interface NewBookRequest extends NextApiRequest {
    body: {
        title: string;
        comment?: string;
        collaborators?: string;
    };
}

export default withSessionRoute(createBook);

// TODO update include permissions!
async function createBook(
    req: NewBookRequest,
    res: NextApiResponse<BookData | ApiError>
) {
    // Return if not post
    if (req.method !== "POST") {
        res.status(405).json({ error: "Method Not Allowed" });
        return;
    }

    // Check if user is logged in
    if (!req.session.user_id) {
        res.status(401).json({ error: "Unauthorized" });
        return;
    }

    // Get user
    const user = await service.user.getById(req.session.user_id);
    const { title } = await req.body;

    // Create book with user as author
    const data: BookData = {
        id: -1,
        title: title as string,
        comment: "",
        owner_user_id: user.id,
        last_updated: new Date(),
    };

    // Add user as author
    const insertedBook = await service.book.insert(data);
    if (insertedBook.id == -1) {
        res.status(500).json({ error: "Internal Server Error" });
        return;
    }

    res.status(200).json(insertedBook);
}
