import { config } from "config";
import { sign } from "jsonwebtoken";
import io from "socket.io-client";

/** Connects to socket server in admin
 * namespace and returns the socket.
 * 
 * This should only be used server side.
 */
export default function getSocketClient() {
    const token = sign(
        {
            api: true,
            date: Date.now(),
        }
        , config.SOCKET_SECRET
    );

    let ws = "ws";
    if (config.NODE_ENV == "production") {
        ws = "wss"
    }

    const client = io(`${ws}://localhost:4000/api`, {
        auth: {
            token,
        },
	rejectUnauthorized:false,
        autoConnect: false,
    });

    client.on("error", (error) => {
        console.log("Socket error", error);
    });
    client.on("connect_error", (error) => {
        console.log("Socket connect error", error);
        client.close();
    });

    return client;
}
