import { fetcher } from "lib/fetcher";
import { withSessionSsr } from "lib/withSession";
import useSWR from "swr";

import { FullBooksBrowser } from "components/books/browser/BooksBrowser";
import { DefaultLayoutWithSidebar } from "components/common/DefaultLayout";

export default function Index() {
    //return <BooksViewer books={books} perms={perms} />;
    const {
        data: fileMap,
        isLoading,
        error,
    } = useSWR<FileMap>("/api/books/fileMap", fetcher);

    return (
        <div className="col-sm-12 col-md-10 col-lg-9 col-xl-8 col-xxl-6 mx-auto">
            {error && <p>Failed to load file map</p>}
            {isLoading ? (
                <p>Loading...</p>
            ) : (
                <FullBooksBrowser rootFolderId={"root"} fileMap={fileMap} />
            )}
        </div>
    );
}

Index.getLayout = function getLayout(page) {
    return <DefaultLayoutWithSidebar> {page} </DefaultLayoutWithSidebar>;
};

// Access for the books for a single user
export interface BookPermission {
    id: number;
    pRead: boolean;
    pWrite: boolean;
    pDelete: boolean;
    pACL: boolean;
}

export const getServerSideProps = withSessionSsr(
    async ({ req, resolvedUrl }) => {
        if (req.session.user_id) {
            return {
                props: {},
            };
        }
        // This should never happen because of the middleware:
        return {
            redirect: {
                destination: `/login?redirect=${resolvedUrl}`,
                permanent: false,
            },
        };
    }
);
