import { useRouter } from "next/router";
import { useEffect, useState } from "react";

import { getLayout } from "./account/login";

/** This route is show if an user does an action for which
 * he is not authorized.
 */
export default function TokenExpired({ expired }) {
    const router = useRouter();
    const [date, setDate] = useState<string>();

    useEffect(() => {
        setDate(new Date(expired).toLocaleString());
    }, [expired]);

    return (
        <>
            <div
                className="d-flex alert alert-warning flex-column"
                role="alert"
                style={{
                    fontWeight: "bold",
                }}
            >
                <p>The token your are trying to use has expired on {date}.</p>
                <p>Please request a new token or login to access your book.</p>
                <button
                    className="btn btn-primary mt-2"
                    onClick={() => {
                        router.push("/");
                    }}
                >
                    Home
                </button>
            </div>
        </>
    );
}

TokenExpired.getLayout = getLayout;

export const getServerSideProps = async (context) => {
    const { expired } = context.query;

    return {
        props: {
            expired,
        },
    };
};
