import { config } from "config";
import { readFileSync } from "fs";
import { IncomingMessage } from "http";
import { ServerResponse } from "http";
import { createServer as createServerHttp } from "http";
import { createServer as createServerHttps } from "https";
import next from "next";
import { getSocketIOServer } from "socket";
import { parse } from "url";

// Own function to setup server
const snip_socket = getSocketIOServer();

// Config for next server
const dev = config.NODE_ENV !== "production";
const hostname = config.HOSTNAME;
const port = 4000;
const dir = "./app";
// when using middleware `hostname` and `port` must be provided below
const app = next({ dev, hostname, port, dir });
const handle = app.getRequestHandler();



// Define the callback function to add as http or https
async function callback_server(
    req: IncomingMessage,
    res: ServerResponse<IncomingMessage>
) {
    // We attach the socket to the request object
    // to use it in the route handler
    // e.g. emitting event on post requests

    try {
        // Be sure to pass `true` as the second argument to `url.parse`.
        // This tells it to parse the query portion of the URL.
      const parsedUrl = parse(req.url, true)
      const { pathname, query } = parsedUrl
 
      if (pathname === '/a') {
        await app.render(req, res, '/a', query)
      } else if (pathname === '/b') {
        await app.render(req, res, '/b', query)
      } else {
        await handle(req, res, parsedUrl)
	}
    } catch (err) {
        console.error("Error occurred handling", req.url, err);
        res.statusCode = 500;
        res.end("internal server error");
    }
}

app.prepare().then(() => {
    let server;
    if (dev) {
        server = createServerHttp(callback_server);
    } else {
        // Load ssl options
        const httpsOptions = {
            key: readFileSync("/usr/src/app/ssl/certificate.key"),
            cert: readFileSync("/usr/src/app/ssl/certificate.crt"),
        };
        // Create server
        server = createServerHttps(httpsOptions, callback_server);
    }
    server.listen(port, () => {
        if (dev) {
            console.log(`> Ready on http://${hostname}:${port}`);
        } else {
            console.log(`> Ready on https://${hostname}:${port}`);
        }
    });

    // Attach socket.io to the http server
    snip_socket.attach(server, { serveClient: false });
});
