import { ArrayData, ArraySnip, ArrayView } from "./array";
import { BaseData, BaseSnip, BaseView, SnipData } from "./base";
import { DoodleData, DoodleSnip, DoodleView } from "./doodle";
import { ImageData,ImageSnip, ImageView } from "./image";
import { TextData, TextSnip, TextView } from "./text";

export function _get_snip_from_data<
    s extends BaseSnip,
    d extends BaseData,
    v extends BaseView
>(snip_data: SnipData<d, v>): s | BaseSnip {
    const type = snip_data.type;

    switch (type) {
        case "text":
            return TextSnip.from_data(
                snip_data as unknown as SnipData<TextData, TextView>
            );
        case "doodle":
            return DoodleSnip.from_data(
                snip_data as unknown as SnipData<DoodleData, DoodleView>
            );
        case "array":
            return ArraySnip.from_data(
                snip_data as unknown as SnipData<ArrayData, ArrayView>
            );
        case "legacy":
        case "image":
            return ImageSnip.from_data(
                snip_data as unknown as SnipData<ImageData, ImageView>
            );
        case "base":
        default:
            console.warn("[Snips] Unexpected snip with type: " + type);
            return BaseSnip.from_data(
                snip_data as unknown as SnipData<BaseData, BaseView>
            );
    }
}
