import { _get_snip_from_data } from "./general";
import { BaseData, BaseSnip, BaseView, SnipData } from "./general/base";
import * as uprp from "./uprp";

/** This function parses the data of a snip and returns
 * a snip object.
 *
 * This can be seen as main entry point to convert a snip from
 * a data dict to a snip object.
 *
 * @param {SnipData} data - The data of the snip
 */
export function get_snip_from_data<
    s extends BaseSnip,
    d extends BaseData,
    v extends BaseView
>(snip_data: SnipData<d, v>): s | BaseSnip {
    // Get the type of the snip
    const type = snip_data.type;

    // Parse Snip and return the right object
    // The type name is prefixed with
    // "[folder]/.../[file]" to avoid name clashes
    // This is not the case for the general snips!
    const type_split = type.split("/");
    if (type_split.length - 1 === 0) {
        // General snips i.e. no namespace
        return _get_snip_from_data(snip_data);
    }
    const namespace = type_split[0];
    switch (namespace) {
        case "uprp":
            return uprp._get_snip_from_data(snip_data);
        default:
            console.warn("[Snips] Unknown snip type: " + type);
            return BaseSnip.from_data(
                snip_data as unknown as SnipData<BaseData, BaseView>
            );
    }
}
