import { AttCtData, AttCtSnip } from "./spec/ginix/attct";
import { LogfileData, LogfileSnip } from "./spec/logfile";
import { MacroSpecData, MacroSpecSnip } from "./spec/macrospec";
import { MotorsData, MotorsSnip, MotorsView } from "./spec/motors";
import { TimestampData, TimestampSnip } from "./spec/timestamp";

import { BaseData, BaseSnip, BaseView, SnipData } from "snips/general/base";
import { ImageData, ImageSnip, ImageView } from "snips/general/image";
import { TextView } from "snips/general/text";

export function _get_snip_from_data<
    s extends BaseSnip,
    d extends BaseData,
    v extends BaseView
>(snip_data: SnipData<d, v>): s | BaseSnip {
    const type = snip_data.type.replace("uprp/", "");

    switch (type) {
        case "spec/logfile":
            return LogfileSnip.from_data(
                snip_data as unknown as SnipData<LogfileData, TextView>
            );
        case "spec/macro.spec":
            return MacroSpecSnip.from_data(
                snip_data as unknown as SnipData<MacroSpecData, TextView>
            );
        case "spec/motors":
            return MotorsSnip.from_data(
                snip_data as unknown as SnipData<MotorsData, MotorsView>
            );
        case "spec/timestamp":
            return TimestampSnip.from_data(
                snip_data as unknown as SnipData<TimestampData, TextView>
            );
        case "spec/ginix/attct":
            return AttCtSnip.from_data(
                snip_data as unknown as SnipData<AttCtData, TextView>
            );
        case "spec/cplot":
        case "spec/livedada":
        case "spec/manta":
        case "spec/matlab":
        case "spec/scope":
            return ImageSnip.from_data(
                snip_data as unknown as SnipData<ImageData, ImageView>
            );
        default:
            console.warn("[Snips] Unexpected snip with type: " + type);
            return BaseSnip.from_data(
                snip_data as unknown as SnipData<BaseData, BaseView>
            );
    }
}
