import { config } from "config";
import { JwtPayload, verify } from "jsonwebtoken";
import { bookAuth } from "lib/access_control/books";
import { verifyToken } from "pages/api/books/[id]/socket_token";
import type { Socket } from "socket.io";

export async function authenticate(socket: Socket, next) {

    // Verify token
    const token = socket.handshake.auth.token;
    const book_id = socket.nsp.name.split("-")[1];

    try {
        // Verify and decode payload
        const decoded = verifyToken(token);
        if (decoded.book_id != book_id) {
            throw new Error("Invalid token, book_id does not match");
        }

        // Set socket data
        socket.book_id = parseInt(decoded.book_id);
        socket.user_id = parseInt(decoded.user_id) || undefined;
        socket.auth_token = decoded.token;

    } catch (error) {
        return next(error);
    }
    return next();
}


export async function add_perms(socket: Socket, next) {
    const perms = await bookAuth(socket.user_id, socket.book_id, socket.auth_token);
    socket.perms = perms;
    return next();
}

export async function update_perms(socket: Socket) {
    const perms = await bookAuth(socket.user_id, socket.book_id, socket.auth_token);
    socket.perms = perms;
    return
}


/** For admin namespace only */
export function authenticateApi(socket: Socket, next) {
    // Verify token
    const token = socket.handshake.auth.token;

    try {
        const decoded = verify(token, config.SOCKET_SECRET) as JwtPayload & { api: boolean, date: Date };

        if (!decoded.api) {
            throw new Error("Invalid token, not an api token");
        }
    } catch (error) {
        return next(error);
    }
    return next();
}