import { config } from "config";
import { constants,existsSync, mkdirSync } from "fs";
import { access, readFile, writeFile } from "fs/promises";
import { registerService } from "lib/registerService";

import { RenderPool } from "./process_pool";

const renderPool = registerService("renderPool", () => {
    const dir = config.SRC_FOLDER + "/app/socket/page";
    return new RenderPool(dir + "/child_process_render.ts", [], {
        cwd: dir + "/../../",
        execArgv: ["-r", "ts-node/register", "-r", "tsconfig-paths/register"],
    });
});

export async function page_preview(
    page_id: number,
    book_id: number,
    force_redraw: boolean
): Promise<string> {
    const dir = config.SRC_FOLDER + "/app/socket/page";

    // Check if page image already exists TODO: check for date
    const img_path = dir + "/../../../database/preview_images/" + book_id + "/";

    if (!existsSync(img_path)) {
        //Create the directory if it doesn't exist
        mkdirSync(img_path, { recursive: true });
    }

    // Check if image exists
    const buffer = access(img_path + page_id + ".jpeg", constants.R_OK)
        .then(async () => {
            // Can be accessed#
            if (force_redraw) {
                //Go to catch
                throw new Error("force redraw");
            }
            const img = await readFile(img_path + page_id + ".jpeg", "base64");
            const buffer = "data:image/jpeg;base64," + img;
            return buffer;
        })
        .catch(async () => {
            // Not accessible
            return await renderPagePromise(page_id).then(
                (buffers) => {
                    // Write image to file
                    const base64Data = buffers["dataurl"].replace(
                        /^data:image\/jpeg;base64,/,
                        ""
                    );
                    //Write img file
                    writeFile(
                        img_path + page_id + ".jpeg",
                        base64Data,
                        "base64"
                    );
                    //Write pdf to file
                    writeFile(
                        img_path + page_id + ".pdf",
                        Buffer.from(buffers["pdf"])
                    );
                    return buffers["dataurl"];
                }
            );
        })
        .catch((err) => {
            console.log(err);
            return "";
        });

    return buffer;
}

async function renderPagePromise(
    page_id: number
): Promise<{ dataurl: string; pdf: Buffer }> {
    return new Promise((resolve) => {
        renderPool.render_page(
            page_id,
            (buffers: { dataurl: string; pdf: Buffer }) => {
                resolve(buffers);
            }
        );
    });
}
