import { log, SocketData } from "socket/socket";

import { page_preview } from "./preview";

import { SQLService } from "database/services";
import type { BaseData, BaseView,SnipData } from "snips/general/base";

export function setupPagesPrefix({ socket }: SocketData) {
    socket.on(
        "page:join",
        async (page_id: number, callback: (success: boolean) => void) => {
            log("[Book: " + socket.book_id + "] join_page " + page_id);
            await socket.join("page-" + String(page_id));
            callback(true);
        }
    );
    socket.on("page:leave", (page_id: number) => {
        log("[Book: " + socket.book_id + "] leave_page " + page_id);
        socket.leave("page-" + String(page_id));
    });
    socket.on(
        "page:getSnips",
        async (
            page_id: number,
            callback: (snips: SnipData<BaseData, BaseView>[]) => void
        ) => {
            const snips = await SQLService.snip.getByPageId(page_id);
            callback(snips);
        }
    );
    socket.on(
        "page:getPreview",
        async (page_id: number, callback: (data: string) => void) => {
            // Check if user has permission to view the page
            if (!(socket.perms.pRead === true)) {
                return socket.emit(
                    "error",
                    "You do not have access to view this book"
                );
            }

            // Outsourced function as it is quite big
            const data = await page_preview(page_id, socket.book_id, false);
            callback(data);
        }
    );
}
